@@ -17,7 +17,7 @@ use constant VALIDATE_IP       => eval 'require Data::Validate::IP;1';
 
 use constant DEBUG => $ENV{JSON_VALIDATOR_DEBUG} || 0;
 
-our $VERSION = '0.83';
+our $VERSION = '0.84';
 our @EXPORT_OK = 'validate_json';
 
 my $HTTP_SCHEME_RE = qr{^https?:};
@@ -81,13 +81,12 @@ sub schema {
 sub singleton { state $validator = shift->new }
 
 sub validate {
-  my ($self, $data, $arg) = @_;
-  my ($schema, $pointer) = ref $arg ? ($arg, undef) : ($self->schema->data, $arg);
+  my ($self, $data, $schema) = @_;
+  $schema ||= $self->schema->data;
   return E '/', 'No validation rules defined.' unless $schema and %$schema;
   local $self->{schema} = Mojo::JSON::Pointer->new($schema);
   local $self->{seen}   = {};
-  return $self->_validate($data, '', $schema) unless $pointer;
-  return $self->_validate($data, '', Mojo::JSON::Pointer->new($schema)->get($pointer));
+  return $self->_validate($data, '', $schema);
 }
 
 sub validate_json {
@@ -270,16 +269,14 @@ sub _resolver {
 
 sub _validate {
   my ($self, $data, $path, $schema) = @_;
-  my $type = $schema->{type} || _guess_schema_type($schema, $data);
-  my @errors;
+  my ($type, @errors);
 
   # Avoid recursion
   return if ref $data and $self->{seen}{"$schema\:$data"}++;
 
   # Make sure we validate plain data and not a perl object
-  if (UNIVERSAL::can($data, 'TO_JSON')) {
-    $data = $data->TO_JSON;
-  }
+  $data = $data->TO_JSON if UNIVERSAL::can($data, 'TO_JSON');
+  $type = $schema->{type} || _guess_schema_type($schema, $data);
 
   # Test base schema before allOf, anyOf or oneOf
   if (ref $type eq 'ARRAY') {
@@ -764,7 +761,7 @@ JSON::Validator - Validate data against a JSON schema
 
 =head1 VERSION
 
-0.83
+0.84
 
 =head1 SYNOPSIS
 
@@ -1051,7 +1048,7 @@ Returns the L<JSON::Validator> object used by L</validate_json>.
 =head2 validate
 
   @errors = $self->validate($data);
-  @errors = $self->validate($data, $schema, $json_path);
+  @errors = $self->validate($data, $schema);
 
 Validates C<$data> against a given JSON L</schema>. C<@errors> will
 contain validation error objects or be an empty list on success.
@@ -1063,14 +1060,6 @@ L</schema>. Example:
 
   $self->validate({hero => "superwoman"}, {type => "object"});
 
-C<$json_path> is optional, but it can be used to point to a given "sub schema"
-inside of L</schema>. Example:
-
-  $self->schema({foo => {type => "object"}});
-  $self->validate({hero => "superwoman"}, "/foo");
-
-C<$json_path> is EXPERIMENTAL.
-
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2014-2015, Jan Henning Thorsen
